<?php

use Hiboutik\Prestashop\HPUtil;


if (!defined('_PS_VERSION_')) {
    exit;
}


require _PS_MODULE_DIR_.'/hiboutik/includes/Hiboutik/HiboutikAPI/autoloader.php';


class Hiboutik extends Module
{
  public function __construct()
  {
    $this->name = 'hiboutik';
    $this->tab = 'quick_bulk_update';
    $this->version = '1.3.1';
    $this->author = 'Hiboutik';
    $this->need_instance = 0;
    $this->ps_versions_compliancy = [
      'min' => '1.6',
      'max' => _PS_VERSION_
    ];
    $this->bootstrap = true;

    parent::__construct();

    $this->displayName = $this->l('Hiboutik');
    $this->description = $this->l('Synchronize Hiboutik POS software and Prestashop');

    $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

    if (!Configuration::get('HIBOUTIK_ACCOUNT') or !Configuration::get('HIBOUTIK_USER')) {
      $this->warning = $this->l('Hiboutik module is not configured');
    }
  }


  /**
   * Installation
   */
  public function install()
  {
    if (!parent::install()) {
        return false;
    }

    $settings = HPUtil::getSettings();
    foreach ($settings as $anInput) {
      if (!Configuration::updateValue($anInput['name'], $anInput['default'])) {
        return false;
      }
    }

    /* Hook actionPaymentConfirmation : https://devdocs.prestashop.com/1.7/modules/concepts/hooks/list-of-hooks/#update-notes
     * Called after a payment has been validated
     * Located in: /classes/order/OrderHistory.php
     * array('id_order' => (int) Order ID);
     */
    $this->registerHook('actionPaymentConfirmation');

    return true;
  }


  /**
   * Uninstallation
   */
  public function uninstall() {
    if (!parent::uninstall() || !Configuration::deleteByName('MYMODULE_NAME')) {
      return false;
    }

    return true;
  }


  /**
   * Manage submitted form
   */
  public function getContent() {
    $output = [];

    $settings = HPUtil::getSettings();
    if (Tools::isSubmit('submit' . $this->name)) {
      foreach ($settings as $input) {
        $value = strval(Tools::getValue($input['name']));
        // HIBOUTIK_SHIPPING_PRODUCT_ID should be able to take the value 0
//        if ($value === false or !Validate::isGenericName($value)) {
        if ($value === false) {
          $output[] = $this->displayError('<li><strong>' . $input['label'] . ' : </strong>'.$this->l('Invalid Configuration value').'</li>');
        } else {
          Configuration::updateValue($input['name'], trim($value));
          $output[] = $this->displayConfirmation('<li><strong>' . $input['label'] . ' : </strong>'.$this->l('Settings updated').'</li>');
        }
      }
    }

    if (Tools::isSubmit('hiboutik_action')) {
      switch ($_POST['hiboutik_action']) {
        case 'sync_hiboutik':
          $result = $this->synchronizeStock();
          if ($result === true) {
            $output[] = $this->displayConfirmation($this->l('Stock synchronized!'));
          } else {
            $output[] = $this->displayError($this->l('Error synchronizing stock: ').$result);
          }
          break;
      }
    }

    return ((count($output) > 0) ? '<ul style="list-style-type:none">' . implode('', $output) . '</ul>' : '') . $this->displayForm();
  }


  /**
   * Create HTML form
   */
  public function displayForm() {
    // Get default language
    $defaultLang = (int) Configuration::get('PS_LANG_DEFAULT');

    // Init Fields form array
    $fieldsForm[0]['form'] = [
      'legend' => [
        'title' => 'Hiboutik Settings',
      ],
      'input' => HPUtil::getSettings(),
      'submit' => [
        'title' => 'Save',
        'class' => 'btn btn-default pull-right'
      ]
    ];

    $helper = new HelperForm();

    // Module, token and currentIndex
    $helper->module = $this;
    $helper->name_controller = $this->name;
    $helper->token = Tools::getAdminTokenLite('AdminModules');
    $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

    // Language
    $helper->default_form_language = $defaultLang;
    $helper->allow_employee_form_lang = $defaultLang;

    // Title and toolbar
    $helper->title = $this->displayName;
    $helper->show_toolbar = true;        // false -> remove toolbar
    $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
    $helper->submit_action = 'submit' . $this->name;
    $helper->toolbar_btn = [
        'save' => [
            'desc' => $this->l('Save'),
            'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
            '&token=' . Tools::getAdminTokenLite('AdminModules'),
        ],
        'back' => [
            'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
            'desc' => $this->l('Back to list')
        ]
    ];

    // Load current value
    foreach ($fieldsForm[0]['form']['input'] as $anInput) {
      $helper->fields_value[$anInput['name']] = Configuration::get($anInput['name']);
    }


    return $helper->generateForm($fieldsForm);
  }




  /**
   * Synchronize sale from Prestashop to Hiboutik
   *
   * @param array $orderParam
   * @return void
   */
  public function hookActionPaymentConfirmation($orderParam) {
    $config = HPUtil::getHiboutikConfiguration();
    $message_retour = [];
$ch = curl_init();
//curl_setopt($ch, CURLOPT_URL, "https://prestashop.hiboutik.net/wh/?account=burgers&type=order&key=7fzly8s0vmd5is1&oid=".$orderParam['id_order']."");
curl_setopt($ch, CURLOPT_URL, "".$config['HIBOUTIK_WEBHOOK_URL']."&oid=".$orderParam['id_order']."");
curl_setopt($ch, CURLOPT_HEADER, 0);
curl_exec($ch);
curl_close($ch);

  }



}
