<?php
namespace Hiboutik\Prestashop;

use Hiboutik\HiboutikAPI;
use \Db;
use \DbQuery;
use \Module;
use \Configuration;


/**
 * @package Hiboutik\Prestashop\HPUtil
 */
class HPUtil
{
  /** @var const */
  const MODULE_NAME = 'hiboutik';
  /** @var const */
  const SECURITY_GET_PARAM = 'k';

  /** @var array Settings declaration */
  public static $settingInput;
  /** @var \Module */
  public static $module;


/**
 * Get settings with translations
 *
 * @param void
 * @return array Settings
 */
  public static function getSettings() {
    if (self::$settingInput === null) {
      if (self::$settingInput === null) {
        self::$module = Module::getInstanceByName(self::MODULE_NAME);
      }
      self::$settingInput = [
        [
          'label' => self::$module->l('HIBOUTIK Webhook', 'HPUtil'),
          'name' => 'HIBOUTIK_WEBHOOK_URL',
          'type' => 'text', 'size' => 255, 'required' => true,
          'default' => '',
          'desc' => self::$module->l('Copy the webhook url from your Prestashop app in your Hiboutik account.')
        ]
      ];
    }
    return self::$settingInput;
  }


/**
  * Get configuration
  */
  public static function getHiboutikConfiguration() {
    $result = [];
    $settings = self::getSettings();
    foreach ($settings as $input) {
      $result[$input['name']] = Configuration::get($input['name']);
    }
    return $result;
  }


/**
 * Connect to Hiboutik API
 *
 * Returns a configured instance of the HiboutikAPI class
 *
 * @param array $config Configuration array
 * @returns Hiboutik\HiboutikAPI
 */
  public static function apiConnect($config)
  {
    if ($config['HIBOUTIK_OAUTH_TOKEN'] == 'no' or $config['HIBOUTIK_OAUTH_TOKEN'] == '') {
      $hiboutik = new HiboutikAPI($config['HIBOUTIK_ACCOUNT'], $config['HIBOUTIK_USER'], $config['HIBOUTIK_KEY']);
    } else {
      $hiboutik = new HiboutikAPI($config['HIBOUTIK_ACCOUNT']);
      $hiboutik->oauth($config['HIBOUTIK_OAUTH_TOKEN']);
    }
    return $hiboutik;
  }


/**
 * Get product's id with reference
 *
 * @param string $ref Prestashop product reference
 * @return string Product id
 */
  public static function getIdByReference($ref)
  {
    if (empty($ref)) {
      return 0;
    }

    $query = new DbQuery();
    $query->select('p.id_product');
    $query->from('product', 'p');
    $query->where('p.reference = \''.pSQL($ref).'\'');

    return Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue($query);
  }


/**
 * Get attributes's id with reference
 *
 * @param string $ref Prestashop product reference
 * @return int Attribute id
 */
  public static function getAttributeIdByRef($ref)
  {
    if (empty($ref)) {
      return 0;
    }

    $query = new DbQuery();
    $query->select('a.id_product_attribute');
    $query->from('product_attribute', 'a');
    $query->where('a.reference = \''.pSQL($ref).'\'');

    return (int) Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue($query);
  }


/**
 * Get product's id with reference to a size
 *
 * @param string $ref Prestashop product reference
 * @return int Attribute id
 */
  public static function getIdByReferenceFromAttr($ref)
  {
    if (empty($ref)) {
      return 0;
    }

    $query = new DbQuery();
    $query->select('a.id_product');
    $query->from('product_attribute', 'a');
    $query->where('a.reference = \''.pSQL($ref).'\'');

    return (int) Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue($query);
  }


/**
 * Generate and check hashes
 *
 * @param string $string Value to hash
 * @param string $key Shared secret key used to generate the HMAC
 * @param string $check_hash Optional; hash to compare
 *
 * @return string|bool
 */
  public static function myHash($string, $key, $check_hash = null)
  {
    $hmac = hash_hmac('sha256', $string, $key);

    if ($check_hash === null) {
      return $hmac;
    }

    // Preventing timing attacks
    if (function_exists('\hash_equals'/* notice the namespace */)) {
      return hash_equals($check_hash, $hmac);
    }

    // Preventing timing attacks for PHP < v5.6.0
    $len_hash = strlen($hmac);
    $len_hash_rcv = strlen($check_hash);
    if ($len_hash !== $len_hash_rcv) {
      return false;
    }
    $equal = true;
    for ($i = $len_hash - 1; $i !== -1; $i--) {
      if ($hmac[$i] !== $check_hash[$i]) {
        $equal = false;
      }
    }
    return $equal;
  }




}
